@@ -1,8 +1,9 @@
-from simple_ddl_parser.utils import remove_par
 import re
 from copy import deepcopy
 from typing import Dict
 
+from simple_ddl_parser.utils import remove_par
+
 
 class AfterColumns:
     def p_expression_partitioned_by(self, p):
@@ -13,7 +14,6 @@ class AfterColumns:
 
 
 class Table:
-
     def p_create_table(self, p):
         """create_table : CREATE TABLE IF NOT EXISTS
         | CREATE TABLE
@@ -164,7 +164,8 @@ class Type:
         p[0] = p[1]
         p[0]["base_type"] = p[2]
         p[0]["properties"] = {}
-        if p[0]["base_type"] == "ENUM":
+        base_type = p[0]["base_type"].upper()
+        if base_type == "ENUM":
             p[0]["properties"]["values"] = p_list[4]
         elif p[0]["base_type"] == "OBJECT":
             if "type" in p_list[4][0]:
@@ -172,6 +173,7 @@ class Type:
         else:
             if isinstance(p_list[-2], list):
                 for item in p_list[-2]:
+                    print(item)
                     p[0]["properties"].update(item)
 
     def p_type_name(self, p):
